@@ -5,6 +5,7 @@ import matplotlib.pyplot as plt
 import pandas as pd
 import numpy as np
 import concurrent.futures
+import datetime
 
 class Plotter:
     def __init__(self, data, style="default"):
@@ -25,7 +26,8 @@ class Plotter:
         """
         #style_path = f"Plotter/{self.style}.mplstyle"  # Look for style in the styles folder
         try: #if os.path.exists(style_path) or style_path in plt.style.available:
-            plt.style.use(style)  # Apply the style
+            if style is not None:
+                plt.style.use(style)  # Apply the style
         except:
             print(
                 f"Warning: Style '{style}' not found. Using default style.")
@@ -46,7 +48,7 @@ class Plotter:
             return aspect
         else:
             aspect_dict = {'small': (6, 4), 'medium': (
-                8, 6), 'big': (10, 8), 'wide': (12, 6)}
+                8, 6), 'big': (10, 8), 'wide': (12, 6), 'very-wide': (24, 4)}
             return aspect_dict.get(aspect, (8, 6))
 
     @staticmethod
@@ -98,6 +100,29 @@ class Plotter:
                     ast.literal_eval)
         return config
 
+    @staticmethod
+    def try_date_ticks(data, var, axis=0):
+        if axis == 0:
+            ticks = plt.xticks
+        elif axis == 1:
+            ticks = plt.yticks
+        try:
+            x_0000 = data[var][data[var].dt.time == datetime.time(0, 0)]
+            if len(x_0000) > 3:
+                if len(data[var].dt.month.unique()) > 3:
+                    ticks([list(x_0000)[int(i)] for i in np.linspace(0, len(x_0000)-1, 5)],
+                        [list(x_0000)[int(i)].strftime("%d/%m/%Y") for i in np.linspace(0, len(x_0000)-1, 5)])
+                else:
+                    ticks([list(x_0000)[int(i)] for i in np.linspace(0, len(x_0000)-1, min(len(x_0000), 5))],
+                        [list(x_0000)[int(i)].strftime("%d/%m") for i in np.linspace(0, len(x_0000)-1, min(len(x_0000), 5))])
+            else:
+                # check if data_fc[x_var] is datetime type
+                ticks([list(data[var])[int(i)] for i in np.linspace(0, len(data)-1, 5)],
+                    [list(data[var])[int(i)].strftime("%d/%m %H:%M") for i in np.linspace(0, len(data)-1, 5)])
+        except Exception as e:
+            print(e)
+        return
+
     def windroseplot(self, config, save_as=None, data=None, opening=0.94, nsector=36, edgecolor='white', dpi=300):
         from windrose import WindroseAxes
 
@@ -144,8 +169,11 @@ class Plotter:
             self.plot(config, *args, **kwargs)
         return
     
-    def plot(self, config, save_as=None, data=None, dpi=None):
+    def plot(self, config, save_as=None, data=None, dpi=None, **kwargs):
         """ Plot based on the configuration from CSV """
+        config.update(kwargs)
+
+        # Apply the selected style
         self.apply_style(self.style)
         
         #self._set_theme(config.get('theme', 'light'), config.get('palette', 'viridis'))
@@ -154,34 +182,49 @@ class Plotter:
             data = self.data  # Use self.data if no data is provided
         
         plt.figure(figsize=Plotter._get_figure_size(
-            config.get('aspect', 'big')))
+            config.get('aspect', 'wide')))
         
         if isinstance(config['y_var'], str):
             config['y_var'] = [config['y_var']]
 
+        # Only keep the columns that are present in the data
+        config['x_var'] = config['x_var'] if config['x_var'] in data.columns else ''
+        config['y_var'] = [y for y in config['y_var'] if y in data.columns]
+
+        if sum([(config[v] not in data.columns) for v in ['hue', 'style', 'size'] if config.get(v, None) is not None]) or \
+                len(config['x_var'])==0 or len(config['y_var'])==0:
+            # print("Error: One or more of the hue, style, or size variables are not in the data.")
+            plt.close()
+            return
+
         for y in config['y_var']:
-            plot = sns.lineplot(data=data, x=config['x_var'], y=y,
+            sns.lineplot(data=data, x=config['x_var'], y=y,
                                 hue=config['hue'], style=config['style'], size=config['size'])
         
-        if config['x_label']:
+        if config.get('x_label', None):
             plt.xlabel(config['x_label'])
-        if config['y_label']:
+        if config.get('y_label', None):
             plt.ylabel(config['y_label'])
-        if config['title']:
+        if config.get('title', None):
             plt.title(config['title'])
-        if config['xlim']:
+        if config.get('xlim', None):
             plt.xlim(config['xlim'])
-        if config['ylim']:
+        if config.get('ylim', None):
             plt.ylim(config['ylim'])
         else:
             plt.ylim(Plotter.optimal_ylim(data[config['y_var']]))
         
+        # Try to set date ticks
+        self.try_date_ticks(data, config['x_var'], axis=0)
+
         # Save the figure if requested
         if save_as:
             plt.savefig(save_as, dpi=dpi)
-            plt.close()
         else:
             plt.show()
+        
+        # Close the plot to avoid memory leaks
+        plt.close()
         return
 
     def serial_plot(self, config, data=None,
@@ -190,11 +233,11 @@ class Plotter:
         # Prepare the list of jobs for multi-processing
         jobs = []
         for index, row in config.iterrows():
-            cfg = row.to_dict()  # Convert row to dictionary
+            cfg = dict(theme=theme, palette=palette, aspect=aspect)
+            cfg.update(row.to_dict())  # Convert row to dictionary
             file_name = cfg.pop('savn', None)
-            cfg.update(dict(theme=theme, palette=palette, aspect=aspect))
 
-            save_as = f"{save_folder}/{file_name}" if save_folder else file_name
+            save_as = f"{save_folder}/{file_name}" if save_folder else None
             kwargs.update(dict(save_as=save_as, data=data))
             if multi_process:
                 jobs.append((cfg, kwargs.copy()))
